@@ -3,12 +3,25 @@ import enum
 from functools import update_wrapper, wraps
 from inspect import signature
 from itertools import groupby
-from typing import List, Sequence, Callable, Any, Optional, Iterator, Set
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    Sequence,
+    Set,
+    Union,
+)
+
 from blinker import signal
-from .validation import validate, validate_value, one_of, ValidationError
+
+from .error import CommandError, InjectionError
 from .transformation import BuildTimeTransformContext, transform, transform_value
 from .utils import tokenize_args, join_generator_string, TokenMismatch, TaggedString, noop
-from .error import CommandError, InjectionError
+from .validation import validate, validate_value, one_of, ValidationError
 
 
 class _Undefined:
@@ -26,21 +39,40 @@ class CommandResult:
         return self.message
 
 
-def _is_enum(choices):
+def _normalize_choices(choices) -> Union[Set[str], Dict[str, str]]:
+    if choices is None:
+        return set()
     try:
-        return issubclass(choices, enum.Enum)
-    except TypeError:
-        # "choices" is not a class (and thus not an enum)
-        return False
+        return _normalize_choices(choices.to_choices())
+    except AttributeError:
+        pass
+    try:
+        return {key: value for key, value in choices.items()}
+    except AttributeError:
+        pass
+    try:
+        # this might work for enums that use string values
+        return {str(choice.name): str(choice.value) for choice in choices}
+    except (AttributeError, TypeError):
+        pass
+    return set(choices)
 
 
 class _Token:
     is_variable = False
     is_placeholder = False
 
-    def __init__(self, value=_Undefined, name=None, is_optional=False,
-                 greedy=False, transform=None, choices=None, description=None,
-                 aliases=None):
+    def __init__(
+            self,
+            value: Any = _Undefined,
+            name: str = None,
+            is_optional: bool = False,
+            greedy: bool = False,
+            transform=None,
+            choices=None,
+            description: str = None,
+            aliases: Iterable = None
+    ):
         """ specify possible value of a command string token
 
         @param choices: may be None, an enum or an iterable
@@ -53,12 +85,7 @@ class _Token:
         self.transform = transform
         self.description = description
         self.aliases = frozenset(aliases or [])
-        if choices is None:
-            self.choices = set()
-        elif _is_enum(choices):
-            self.choices = {item.value for item in choices}
-        else:
-            self.choices = set(choices)
+        self.choices = _normalize_choices(choices)
 
     def matches(self, value):
         if self.value is not _Undefined:
@@ -70,7 +97,7 @@ class _Token:
         if self.name and self.choices:
             # if choices were defined we must validate that the provided
             # value actually is one of those choices
-            validate_value(one_of(self.choices), value)
+            validate_value(one_of(set(self.choices)), value)
         return True
 
     def get_label(self, with_error=None):
@@ -587,6 +614,9 @@ def create_commander(name, description=None):
 
         def __call__(self, *tokens, parent=None, is_abstract=False, group=None, inject=None,
                      is_disabled=False) -> Callable:
+            tokens = list(tokens)
+            if len(tokens) > 0 and isinstance(tokens[0], _Command):
+                parent = tokens.pop(0)
             tokens = _normalize_tokens(tokens)
             injections = _normalize_injections(inject)
 
